@@ -222,6 +222,11 @@ class SlideData:
         if self.backend:
             out.append(f"backend={repr(self.backend)}")
         out.append(f"image shape: {self.shape}")
+        try:
+            nlevels = self.slide.level_count
+        except:
+            nlevels = 1
+        out.append(f"number of levels: {nlevels}")
         out.append(repr(self.tiles))
         out.append(repr(self.masks))
         if self.tiles:
@@ -246,11 +251,12 @@ class SlideData:
         pipeline,
         distributed=True,
         client=None,
-        tile_size=3000,
+        tile_size=256,
         tile_stride=None,
         level=0,
         tile_pad=False,
         overwrite_existing_tiles=False,
+        write_dir=None,
     ):
         """
         Run a preprocessing pipeline on SlideData.
@@ -260,7 +266,7 @@ class SlideData:
             pipeline (pathml.preprocessing.pipeline.Pipeline): Preprocessing pipeline.
             distributed (bool): Whether to distribute model using client. Defaults to True.
             client: dask.distributed client
-            tile_size (int, optional): Size of each tile. Defaults to 3000px
+            tile_size (int, optional): Size of each tile. Defaults to 256px
             tile_stride (int, optional): Stride between tiles. If ``None``, uses ``tile_stride = tile_size``
                 for non-overlapping tiles. Defaults to ``None``.
             level (int, optional): Level to extract tiles from. Defaults to ``None``.
@@ -269,6 +275,9 @@ class SlideData:
                 Defaults to ``False``.
             overwrite_existing_tiles (bool): Whether to overwrite existing tiles. If ``False``, running a pipeline will
                 fail if ``tiles is not None``. Defaults to ``False``.
+            write_dir (str): Path to directory to write the processed slide to. The processed SlideData object
+                will be written to the directory immediately after the pipeline has completed running.
+                The filepath will default to "<write_dir>/<slide.name>.h5path. Defaults to ``None``.
         """
         assert isinstance(
             pipeline, pathml.preprocessing.pipeline.Pipeline
@@ -287,9 +296,22 @@ class SlideData:
                 for tile_key in self.tiles.keys:
                     self.tiles.remove(tile_key)
 
+        # TODO: be careful here since we are modifying h5 outside of h5manager
+        # look into whether we can push this into h5manager
+
+        if tile_stride is None:
+            tile_stride = tile_size
+        elif isinstance(tile_stride, int):
+            tile_stride = (tile_stride, tile_stride)
+
+        self.h5manager.h5["tiles"].attrs["tile_stride"] = tile_stride
+
+        shutdown_after = False
+
         if distributed:
             if client is None:
                 client = dask.distributed.Client()
+                shutdown_after = True
 
             # map pipeline application onto each tile
             processed_tile_futures = []
@@ -311,6 +333,9 @@ class SlideData:
             ):
                 self.tiles.add(tile)
 
+            if shutdown_after:
+                client.shutdown()
+
         else:
             for tile in self.generate_tiles(
                 level=level, shape=tile_size, stride=tile_stride, pad=tile_pad
@@ -320,6 +345,9 @@ class SlideData:
                 pipeline.apply(tile)
                 self.tiles.add(tile)
 
+        if write_dir:
+            self.write(Path(write_dir) / f"{self.name}.h5path")
+
     @property
     def shape(self):
         """
@@ -334,6 +362,24 @@ class SlideData:
         else:
             return self.slide.get_image_shape()
 
+    def extract_region(self, location, size, *args, **kwargs):
+        """
+        Extract a region of the image.
+        This is a convenience method which passes arguments through to the ``extract_region()`` method of whichever
+        backend is in use. Refer to documentation for each backend.
+
+        Args:
+            location (Tuple[int, int]): Location of top-left corner of tile (i, j)
+            size (Union[int, Tuple[int, int]]): Size of each tile. May be a tuple of (height, width) or a
+                single integer, in which case square tiles of that size are generated.
+            *args: positional arguments passed through
+            **kwargs: keyword arguments passed through
+
+        Returns:
+            np.ndarray: image at the specified region
+        """
+        return self.slide.extract_region(location, size, *args, **kwargs)
+
     def generate_tiles(self, shape=3000, stride=None, pad=False, **kwargs):
         """
         Generator over Tile objects containing regions of the image.
@@ -343,7 +389,7 @@ class SlideData:
 
         Args:
             shape (int or tuple(int)): Size of each tile. May be a tuple of (height, width) or a single integer,
-                in which case square tiles of that size are generated.
+                in which case square tiles of that size are generated. Defaults to 256px.
             stride (int): stride between chunks. If ``None``, uses ``stride = size`` for non-overlapping chunks.
                 Defaults to ``None``.
             pad (bool): How to handle tiles on the edges. If ``True``, these edge tiles will be zero-padded
@@ -520,6 +566,7 @@ pathmlext = {".h5", ".h5path"}
 openslideext = {
     ".svs",
     ".tif",
+    ".tiff",
     ".ndpi",
     ".vms",
     ".vmu",
